@@ -3,7 +3,8 @@ from .core import (
     abrir_planilha,
     tratar_colunas_df,
     gsheet_to_df,
-    plotar_tabela_aggrid_colher_selecao
+    plotar_tabela_aggrid_colher_selecao,
+    tratar_colunas_df_para_insercao_gsheet
 )
 
 __all__ = [
@@ -11,5 +12,6 @@ __all__ = [
     "abrir_planilha",
     "tratar_colunas_df",
     "gsheet_to_df",
-    "plotar_tabela_aggrid_colher_selecao"
+    "plotar_tabela_aggrid_colher_selecao",
+    "tratar_colunas_df_para_insercao_gsheet"
 ]
