@@ -261,42 +261,61 @@ def tratar_colunas_df_para_insercao_gsheet(
         df_insercao: pd.DataFrame, # DataFrame a ser inserido
         lista_colunas_data: Optional[list] = None, # Lista de colunas de data
         lista_colunas_data_hora: Optional[list] = None, # Lista de colunas de data e hora
+        lista_colunas_hora: Optional[list] = None, # Lista de colunas de hora
         lista_colunas_str: Optional[list] = None, # Lista de colunas string
         lista_colunas_int: Optional[list] = None, # Lista de colunas inteiras
         lista_colunas_float: Optional[list] = None # Lista de colunas float
     ) -> pd.DataFrame:
 
-    for coluna in lista_colunas_data:
+    if lista_colunas_data:
 
-        if coluna in df_insercao.columns:
+        for coluna in lista_colunas_data:
 
-            df_insercao[coluna] = pd.to_datetime(df_insercao[coluna]).dt.strftime('%Y-%m-%d')
+            if coluna in df_insercao.columns:
 
-    for coluna in lista_colunas_data_hora:
+                df_insercao[coluna] = pd.to_datetime(df_insercao[coluna]).dt.strftime('%Y-%m-%d').fillna('')
 
-        if coluna in df_insercao.columns:
+    if lista_colunas_data_hora:
 
-            df_insercao[coluna] = pd.to_datetime(df_insercao[coluna]).dt.strftime('%Y-%m-%d %H:%M:%S')
+        for coluna in lista_colunas_data_hora:
 
-    for coluna in lista_colunas_str:
+            if coluna in df_insercao.columns:
 
-        if coluna in df_insercao.columns:
+                df_insercao[coluna] = pd.to_datetime(df_insercao[coluna]).dt.strftime('%Y-%m-%d %H:%M:%S').fillna('')
 
-            df_insercao[coluna] = df_insercao[coluna].fillna('').astype(str)
+    if lista_colunas_hora:
 
-    for coluna in lista_colunas_int:
+        for coluna in lista_colunas_hora:
 
-        if coluna in df_insercao.columns:
+            if coluna in df_insercao.columns:
 
-            df_insercao[coluna] = df_insercao[coluna].fillna(0).astype(int).astype(str)
+                df_insercao[coluna] = pd.to_datetime(df_insercao[coluna]).dt.strftime('%H:%M:%S').fillna('')
 
-    for coluna in lista_colunas_float:
+    if lista_colunas_str:
 
-        if coluna in df_insercao.columns:
+        for coluna in lista_colunas_str:
 
-            df_insercao[coluna] = df_insercao[coluna].fillna(0).astype(float).round(2).astype(str)
+            if coluna in df_insercao.columns:
+
+                df_insercao[coluna] = df_insercao[coluna].fillna('').astype(str)
+
+    if lista_colunas_int:
+
+        for coluna in lista_colunas_int:
+
+            if coluna in df_insercao.columns:
+
+                df_insercao[coluna] = df_insercao[coluna].fillna(0).astype(int).astype(str)
+
+    if lista_colunas_float:
+
+        for coluna in lista_colunas_float:
+
+            if coluna in df_insercao.columns:
+
+                df_insercao[coluna] = df_insercao[coluna].fillna(0).astype(float).round(2).astype(str)
+
+                df_insercao[coluna] = df_insercao[coluna].apply(lambda x: x.replace('.', ','))
 
-            df_insercao[coluna] = df_insercao[coluna].apply(lambda x: x.replace('.', ','))
-            
     return df_insercao
 
